#
# spec file for package kwidgetsaddons
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define lname   libKF5WidgetsAddons5
%define _tar_path 5.71
# Full KF5 version (e.g. 5.33.0)
%{!?_kf5_version: %global _kf5_version %{version}}
# Last major and minor KF5 version (e.g. 5.33)
%{!?_kf5_bugfix_version: %define _kf5_bugfix_version %(echo %{_kf5_version} | awk -F. '{print $1"."$2}')}
%bcond_without lang
Name:           kwidgetsaddons
Version:        5.71.0
Release:        lp152.1.1
Summary:        Large set of desktop widgets
License:        LGPL-2.1-or-later
Group:          System/GUI/KDE
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz
%if %{with lang}
Source1:        https://download.kde.org/stable/frameworks/%{_tar_path}/%{name}-%{version}.tar.xz.sig
Source2:        frameworks.keyring
%endif
Source99:       baselibs.conf
BuildRequires:  cmake >= 3.0
BuildRequires:  extra-cmake-modules >= %{_kf5_bugfix_version}
BuildRequires:  fdupes
BuildRequires:  kf5-filesystem
BuildRequires:  cmake(Qt5Test) >= 5.12.0
BuildRequires:  cmake(Qt5UiPlugin) >= 5.12.0
BuildRequires:  cmake(Qt5UiTools) >= 5.12.0
BuildRequires:  cmake(Qt5Widgets) >= 5.12.0
%if %{with lang}
BuildRequires:  cmake(Qt5LinguistTools) >= 5.12.0
%endif

%description
This repository contains add-on widgets and classes for applications
that use the Qt Widgets module. If you are porting applications from
KDE Platform 4 "kdeui" library, you will find many of its classes here.

%package -n %{lname}
Summary:        Large set of desktop widgets
Group:          System/GUI/KDE
%requires_ge    libQt5Widgets5
Obsoletes:      libKF5WidgetsAddons4
%if %{with lang}
Recommends:     %{lname}-lang = %{version}
%endif

%description -n %{lname}
This repository contains add-on widgets and classes for applications
that use the Qt Widgets module. If you are porting applications from
KDE Platform 4 "kdeui" library, you will find many of its classes here.

%package devel
Summary:        Large set of desktop widgets: Build Environment
Group:          Development/Libraries/KDE
Requires:       %{lname} = %{version}
Requires:       extra-cmake-modules
Requires:       cmake(Qt5Widgets) >= 5.12.0

%description devel
This repository contains add-on widgets and classes for applications
that use the Qt Widgets module. If you are porting applications from
KDE Platform 4 "kdeui" library, you will find many of its classes here.
Development files.

%lang_package -n %{lname}

%prep
%setup -q

%build
  %cmake_kf5 -d build -- -Dlconvert_executable=%{_kf5_libdir}/qt5/bin/lconvert
  %cmake_build

%install
  %kf5_makeinstall -C build
  %fdupes %{buildroot}

%if %{with lang}
%find_lang %{name}5 --with-qt --without-mo
%endif

%post -n %{lname} -p /sbin/ldconfig
%postun -n %{lname} -p /sbin/ldconfig

%if %{with lang}
%files -n %{lname}-lang -f %{name}5.lang
%endif

%files -n %{lname}
%license COPYING*
%doc README*
%{_kf5_datadir}/kcharselect/
%{_kf5_libdir}/libKF5WidgetsAddons.so.*

%files devel
%{_kf5_libdir}/libKF5WidgetsAddons.so
%{_kf5_libdir}/cmake/KF5WidgetsAddons/
%{_kf5_includedir}/
%dir %{_kf5_plugindir}/designer
%{_kf5_plugindir}/designer/kwidgetsaddons5widgets.so
%{_kf5_mkspecsdir}/qt_KWidgetsAddons.pri

%changelog
* Sun Jun  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.71.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.71.0
- Changes since 5.70.0:
  * Be noisy about deprecated KPageWidgetItem::setHeader(empty-non-null string)
  * Use UI marker context in more tr() calls
* Sun May  3 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.70.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.70.0
- Changes since 5.69.0:
  * [KFontChooser] Remove NoFixedCheckBox DisplayFlag, redundant
  * [KFontChooser] Add new DisplayFlag; modify how flags are used
  * [KCharSelect] Minor code optimisation
  * [KFontChooser] Make styleIdentifier() more precise by adding font styleName (kde#420287)
  * [KFontRequester] Port from QFontDialog to KFontChooserDialog
  * [KMimeTypeChooser] Add the ability to filter the treeview with a QSFPM (kde#245637)
  * [KFontChooser] Make the code slightly more readable
  * [KFontChooser] Add a checkbox to toggle showing only monospaced fonts
  * [KFontChooser] More code cleanup
  * Remove not necessary include
* Sun Apr  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.69.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/kde-frameworks-5.69.0
- Changes since 5.68.0:
  * [KCharSelect] Do not simplify single characters in search (kde#418461)
  * Fix warning about incompatible enum types
  * [KFontChooser] General code cleanup
  * Copy KFontDialog from KDELibs4Support to KWidgetAddons, now KFontChooserDialog
  * autotests: make ktooltipwidgettest more robust
  * Port away from deprecated QSet methods
  * It we readd items we need to clear it first. OTherwise we will see
  * Update kcharselect-data to Unicode 13.0
* Sun Mar  8 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.68.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.68.0.php
- Changes since 5.67.0:
  * [KMessageWidget] Allow the style to change our palette
  * [KMessageWidget] Draw it with QPainter instead of using stylesheet
  * Slightly reduce level 1 heading size
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Sun Feb  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.67.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.67.0.php
- Changes since 5.66.0:
  * QApplication::globalStrut() will be removed in qt6.
  * [KMessageWidget] Subtract the correct margin
  * [KMessageBox] Only allow selecting text in the dialog box
    using the mouse (kde#416204)
  * [KMessageWidget] Use devicePixelRatioF for animation pixmap (kde#415528)
* Sun Jan  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.66.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.66.0.php
- Changes since 5.65.0:
  * Port QRegExp to QRegularExpression
  * Port deprecated toList() method
  * Update the obsolete projects.kde.org URL
* Sun Dec  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.65.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.65.0.php
- Changes since 5.64.0:
  * [KSqueezedTextLabel] Add icon for "Copy entire text" action
  * Remove unused signal we can use directly "signal(const QUrl&)
  * Unify KPageDialog margin handling into KPageDialog itself (kde#413181)
* Sun Nov  3 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.64.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.64.0.php
- Changes since 5.63.0:
  * Set QT_DISABLE_DEPRECATED_BEFORE=0x050d00
  * Use ECMGenerateExportHeader to manage deprecated API better
* Sun Oct  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.63.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.63.0.php
- Too many changes to list here.
* Sat Sep  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.62.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.62.0.php
- Changes since 5.61.0:
  * [KMessageWidget] Pass widget to standardIcon()
  * Remove unused includes
  * Add option to build Qt Designer plugin (BUILD_DESIGNERPLUGIN, default ON)
* Wed Aug  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.61.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.61.0.php
- Changes since 5.60.0:
  * Remove explicit use of ECM_KDE_MODULE_DIR, is part of ECM_MODULE_PATH
  * introduce concept of header and footer for kpageview
  * QPalette::background -> QPalette::window
  * [Busy Indicator] Match duration of QQC2-desktop-style version
  * Add a warning dialog with a collapsible details section.
  * Remove unused includes
  * new class KBusyIndicatorWidget similar to QtQuick's BusyIndicator
* Fri Jul 19 2019 Wolfgang Bauer <wbauer@tmo.at>
- Don't lower minimum Qt version anymore, it requires 5.11 now
- Drop patch to support Qt 5.9:
  * 0001-Do-not-use-AnimationDuration-if-Qt-lt-5.10.patch
* Sun Jul 14 2019 lbeltrame@kde.org
- Update to 5.60.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.60.0.php
- Changes since 5.59.0:
  * set the focusPolicy of kpasswordlineedit to the policy of its proxy (kde#398275)
  * Replace "Details" button with KCollapsibleGroupBox
* Sun Jun  9 2019 lbeltrame@kde.org
- Update to 5.59.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.59.0.php
- Changes since 5.58.0:
  * KNewPasswordDialog: add periods to message widgets
  * Port some deprecated methods
* Wed May 15 2019 lbeltrame@kde.org
- Update to 5.58.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.58.0.php
- Changes since 5.57.0:
  * autotests: fix kcharselect unittest so it can find the data file uninstalled
  * KCharSelect: remove unnecessary call
  * KCharSelect: add unittest. Hits the assert in QHeaderView.
  * Update kcharselect-data to Unicode 12.1
  * KCharSelect's internal model: ensure rowCount() is 0 for valid indexes
  * Replace count() == 0 by isEmpty()
* Sun Apr 14 2019 lbeltrame@kde.org
- Update to 5.57.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.57.0.php
- Changes since 5.56.0:
  * Port std::sort
  * Make KFontRequester consistent
  * Update kcharselect-data to Unicode 12.0
* Sun Mar 10 2019 lbeltrame@kde.org
- Update to 5.56.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.56.0.php
- Changes since 5.55.0:
  * Remove deprecated method
  * Port deprecated methods
  * Use correct KStandardGuiItem "no" icon
* Fri Feb 15 2019 alarrosa@suse.com
- Add 0001-Do-not-use-AnimationDuration-if-Qt-lt-5.10.patch to build with
  Qt 5.9
- Downgrade the Qt version requirement to build with 5.9
* Sun Feb 10 2019 lbeltrame@kde.org
- Update to 5.55.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.55.0.php
- Changes since 5.54.0:
  * Fix zero as nullptr constant warning
  * [KWidgetsAddons] Do not use light font styles for headings (3/3)
  * KRatingPainter: Delete copy constructor and assignment operator
  * delete copy constructor and assignment operator of some internal classes
  * Remove Qt version check
* Mon Jan 14 2019 lbeltrame@kde.org
- Update to 5.54.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.54.0.php
- Changes since 5.53.0:
  * Port to for(...:...) + use reserve
  * [KMessageBox] Fix minimum dialog size when details are requested (kde#401466)
* Sun Dec  9 2018 lbeltrame@kde.org
- Update to 5.53.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.53.0.php
- Changes since 5.52.0:
  * Use isEmpty()
  * Add level api from Kirigami.Heading
  * [KActionMenu] Add apidox to addAction()
* Sun Nov 11 2018 lbeltrame@kde.org
- Update to 5.52.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.52.0.php
- Changes since 5.51.0:
  * Have more include guards match file the name
  * Include own header first
  * Include own _p header as second
  * API dox: fix typo
  * Use more explicit constructors with internal classes
  * API dox: fix "Since" note of KPageWidgetItem::isHeaderVisible
  * Use more new style connect()
  * Do not mix const & non-const iterators
  * Use normalized signatures with Q_ARG()
  * Do not return a value in a void function
  * Use Q_OBJECT with all QObject subclasses (helps debugging introspection)
  * Use QString::remove(foo) over QString::replace(foo, "")
  * Use emit properly and for all signals
  * More const ref arg passing
  * Use QString(), not QStringLiteral("") (where isNull() not relevant)
  * add a new property headerVisible
  * Remove unused variables
  * Call reserve() on Qt containers if fill size is known before
* Tue Oct 16 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Mon Oct 15 2018 lbeltrame@kde.org
- Update to 5.51.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.51.0.php
- Changes since 5.50.0:
  * Remove misleading use of KDE_INSTALL_PYTHONBINDINGSDIR
  * [KCollapsibleGroupBox] Respect style's widget animation duration (kde#397103)
  * Remove obsolete Qt version check
  * Use QString's multi-arg with multiple string args
  * Fix minor EBN issues
* Thu Sep 13 2018 lbeltrame@kde.org
- Update to 5.50.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.50.0.php
- Changes since 5.49.0:
  * Create a first example of the use of KMessageBox
  * Fix two bugs in KMessageWidget
  * [KMessageBox] Call style for icon
  * Add workaround for labels with word-wrapping
* Sun Aug 19 2018 christophe@krop.fr
- Update to 5.49.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.49.0.php
- Changes since 5.48.0:
  * Fix KTimeComboBox input mask for AM/PM times (kde#361764)
  * Honor BUILD_TESTING
* Mon Jul 16 2018 lbeltrame@kde.org
- Update to 5.48.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.48.0.php
- Changes since 5.47.0:
  * Use more nullptr
  * [KMessageWidget] Update stylesheet when palette changes
  * Update kcharselect-data to Unicode 11.0
  * [KCharSelect] Port generate-datafile.py to Python 3
  * Revert "Update kcharselect-data to Unicode 11.0"
  * Update kcharselect-data to Unicode 11.0
  * [KCharSelect] Prepare translations for Unicode 11.0 update
* Tue Jun 12 2018 lbeltrame@kde.org
- Update to 5.47.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.47.0.php
- Changes since 5.46.0:
  * Warning--
  * Use override
  * [KCharSelect] Fix table cell size with Qt 5.11
  * [API dox] Remove usage of \overload, resulting in broken docs
  * [API dox] Tell doxygen "e.g." does not end the sentence, use ".\ "
  * [API dox] Remove unneeded HTML escaping
  * Don't automatically set the default icons for each style
  * Make KMessageWidget match Kirigami inlineMessage's style (kde#385299, kde#381255)
* Sun May 13 2018 lbeltrame@kde.org
- Update to 5.46.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.46.0.php
- Changes since 5.45.0:
  * Warning--
* Sat Apr 14 2018 lbeltrame@kde.org
- Update to 5.45.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.45.0.php
- Changes since 5.44.0:
  * Fix compile with older Qt
  * KColorButtonTest: remove todo code
  * ktooltipwidget: Subtract margins from available size
  * [KAcceleratorManager] Only set iconText() if actually changed (kde#391002)
  * ktooltipwidget: Prevent offscreen display
  * KCapacityBar: set QStyle::State_Horizontal state
  * Sync with KColorScheme changes
  * ktooltipwidget: Fix tooltip positioning
* Mon Mar 12 2018 lbeltrame@kde.org
- Update to 5.44.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.44.0.php
- Changes since 5.43.0:
  * None
* Mon Feb 12 2018 lbeltrame@kde.org
- Update to 5.43.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.43.0.php
- Changes since 5.42.1:
  * autotest: enforce en_US locale and make it pass (it was relying on fr, oops)
  * Fix compiler warning, a quint16 is always <= 0xFFFF
  * autotests: more QCOMPAREs to debug CI failure
  * KDateComboBox: fix dateChanged() not emitted after typing a date (kde#364200)
  * KMultiTabBar: Fix regression in conversion to new style connect()
* Tue Jan 16 2018 lbeltrame@kde.org
- Update to 5.42.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.42.1.php
- Changes since 5.41.0:
  * KMultiTabBar: Fix regression in conversion to new style connect()
  * Remove obsolete reviewboardrc file
  * Fix crash in setMainWindow on wayland
  * Convert to new connect api
  * Port some code to new connect api
  * remove not necessary virtual keyword here
  * Port some code to new connect api
  * Initialize variable, minor optimization
  * QTest::qWaitForWindowExposed uses Q_REQUIRED_RESULT
* Sun Dec 17 2017 lbeltrame@kde.org
- Update to 5.41.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.41.0.php
- Changes since 5.40.0:
  * Avoid inconsistent passworddialog
  * Set enable_blur_behind hint on demand.
  * KDateComboBox: port to Qt5 connect syntax, remove Q_PRIVATE_SLOTs.
  * autotests: replace member with local scoped pointer
  * KPageListView: Update width on font change
* Mon Nov 13 2017 lbeltrame@kde.org
- Update to 5.40.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.40.0.php
- Changes since 5.39.0:
  * fix createKMessageBox focus widget inconsistency
  * more compact password dialog (kde#381231)
  * Unbreak build: Add missing QScrollBar include
  * Set KPageListView width properly
  * autotests: add missing include <functional>
* Mon Oct 23 2017 lbeltrame@kde.org
- Update to 5.39.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.39.0.php
- Changes since 5.38.0:
  * KAcceleratorManager: set icon text on actions to remove CJK markers (kde#365050, kde#377859)
  * KSqueezedTextLabel: Squeeze text when changing indent or margin
  * Use edit-delete icon for destructive discard action (kde#385158)
  * Fix Bug 306944 - Using the mousewheel to increment/decrement the dates (kde#306944)
  * Add autotest for KAcceleratorManager
  * KMessageBox: Use question mark icon for question dialogs
  * Attempt to fix KSqueezedTextLabel unit test
  * KSqueezedTextLabel: Respect indent, margin and frame width
  * KSqueezedTextLabel: Add several autotests
* Tue Sep 12 2017 lbeltrame@kde.org
- Update to 5.38.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.38.0.php
- Changes since 5.37.0:
  * simplify setContents by letting Qt do more of the work
  * KSqueezedTextLabel: Add isSqueezed() for convenience
  * KSqueezedTextLabel: Small improvements to API docs
  * [KPasswordLineEdit] Set focus proxy to line edit (kde#383653)
  * [KPasswordDialog] Reset geometry property
  * Tag some more private classes with hidden visibility
  * Do not leak symbols of pimpl classes, protect with Q_DECL_HIDDEN
- Dropped patches, now upstream:
  * 0001-KPasswordDialog-Reset-geometry-property.patch
  * 0001-KPasswordLineEdit-Set-focus-proxy-to-line-edit.patch
* Wed Aug 23 2017 fabian@ritter-vogt.de
- Add upstream patch to fix geometry of password dialogs:
  * 0001-KPasswordDialog-Reset-geometry-property.patch
* Fri Aug 18 2017 christophe@krop.fr
- Add 0001-KPasswordLineEdit-Set-focus-proxy-to-line-edit.patch
  (kde#383653)
* Sat Aug 12 2017 christophe@krop.fr
- Update to 5.37.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.37.0.php
- Changes since 5.36.0 :
  * CHANGELOG: Extract lineedit password widget
  * KNewPasswordWidget: test whether we hide verification line edit.
  * turn setColumnCount no-op when the column count doesn't change
  * do not crash qaccessible by causing a resize in a resize event (kde#374933)
  * [KPageListViewDelegate] Pass widget to drawPrimitive in drawFocus
* Wed Jul 12 2017 lbeltrame@kde.org
- Update to 5.36.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.36.0.php
- Changes since 5.35.0:
  * Update kcharselect-data to Unicode 10.0
  * Another missing since tag.
  * Add missing @since tag
  * [FEATURE] Option to build & install QCH file with the public API dox
* Sun Jun 11 2017 lbeltrame@kde.org
- Update to 5.35.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.35.0.php
- Changes since 5.34.0:
  * KViewStateSerializer: Fix crash when view is destroyed before state serializer (kde#353380)
  * Use explicit flag values or explicit constructor instead of nullptr
  * API dox: fix-up improvements for "null pointer" changes
  * API dox: use "null pointer" instead of "0"
  * API dox: document enum items directly, not by a separate free-text list
  * API dox: fix wrong usage of @see for direct links
  * API dox: use @see as last, for consistency
  * API dox: move comment before namespace that is documented
  * API dox: add some minimal content to have doxygen consider it documented
* Mon May 15 2017 fabian@ritter-vogt.de
- Update to 5.34.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.34.0.php
- Changes since 5.33.0:
  * KNewPasswordWidget: don't hide visibility action in plaintext mode
  * KPasswordDialog: don't hide visibility action in plaintext mode (kde#378276)
  * Fix KActionSelectorPrivate::insertionIndex()
* Sat Apr 15 2017 lbeltrame@kde.org
- Update to 5.33.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.33.0.php
- Changes since 5.32.0:
  * Upgrade ECM and KF5 version requirements for 5.33.0 release.
  * support building against a qt without a11y enabled
  * Fix wrong size hint when animatedShow is called with hidden parent
  * Fix characters in KCharSelectTable getting elided
  * Enable all planes in kcharselect test dialog
  * Upgrade KF5 version to 5.33.0.
* Sun Mar 19 2017 lbeltrame@kde.org
- Update to 5.32.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/kde-frameworks-5.32.0.php
- Changes since 5.31.0:
  * Commit translations from l10n-kf5
  * Upgrade ECM and KF5 version requirements for 5.32.0 release.
  * Fix API dox still referring to KAction
  * Fix conversion warnings on MSVC: size_t -> uint
  * Fix APIDOX issues raised by clang's -Wdocumentation
  * KToolTipWidget: hide tooltip in enterEvent if hideDelay is zero
  * autotest: remove dependency on UiTools by compiling the ui files into the test
  * Fix KEditListWidget losing the focus on click of buttons
  * Add decomposition of Hangul Syllables into Hangul Jamo
  * Upgrade KF5 version to 5.32.0.
  * KToolTipWidget: small apidox fix
  * KMessageWidget: fix behaviour on overlapping calls of animatedShow/animatedHide
* Thu Feb  9 2017 hrvoje.senjan@gmail.com
- Update to 5.31.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.31.0.php
* Sun Jan  8 2017 hrvoje.senjan@gmail.com
- Update to 5.30.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.30.0.php
* Sun Dec  4 2016 hrvoje.senjan@gmail.com
- Update to 5.29.0
  * Prevent crashing on Mac
  * Don't replace icons with the result of a failed lookup
  * KMessageWidget: fix layout when wordWrap is
    enabled without actions
  * KCollapsibleGroupBox: don't hide widgets,
    override focus policy instead
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.29.0.php
* Sat Nov  5 2016 hrvoje.senjan@gmail.com
- Update to 5.28.0
  * Move kcharselect-generate-datafile.py to src subdir
  * Import kcharselect-generate-datafile.py script with history
  * Remove outdated section
  * Add Unicode copyright and permission notice
  * Fix warning: Missing override
  * Add symbol SMP blocks
  * Fix "See also" references
  * Add missing Unicode blocks; improve ordering (kde#298010)
  * Add character categories to the data file
  * Update the Unicode categories in the data file generation script
  * Adjust the data file generation file to be able to parse the
    unicode 5.2.0 data files
  * Forward port fix for generating translations
  * Let the script to generate the data file for kcharselect also
    write a translation dummy
  * Add the script to generate the data file for KCharSelect
  * New KCharSelect application
    (using kcharselect widget from kdelibs now)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.28.0.php
* Sun Oct  2 2016 hrvoje.senjan@gmail.com
- Update to 5.27.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.27.0.php
* Tue Sep  6 2016 hrvoje.senjan@gmail.com
- Update to 5.26.0
  * Fix background of non-BMP characters
  * Add C octal escaped UTF-8 search
  * Make the default KMessageBoxDontAskAgainMemoryStorage
    save to QSettings
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.26.0.php
* Sun Aug  7 2016 hrvoje.senjan@gmail.com
- Update to 5.25.0
  * Qt >= 5.5 is now required
  * [KCharSelect] Fix crash when searching with no
    present data file (kde#300521)
  * [KCharSelect] Handle characters outside BMP (kde#142625)
  * [KCharSelect] Update kcharselect-data to Unicode 9.0.0
    (kde#336360)
  * KCollapsibleGroupBox: Stop animation in destructor if still running
  * Update to Breeze palette (sync from KColorScheme)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.25.0.php
* Wed Jul  6 2016 hrvoje.senjan@gmail.com
- Update to 5.24.0
  * Fix reading Unihan data
  * Fix minimum size of KNewPasswordDialog (kde#342523)
  * Fix ambiguous contructor on MSVC 2015
  * Fix an alignment issue under the OS X native "macintosh" style
    (kde#296810)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.24.0.php
* Mon Jun  6 2016 hrvoje.senjan@gmail.com
- Update to 5.23.0
  * Use selected icon effect for current KPageView page
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.23.0.php
* Sat May  7 2016 hrvoje.senjan@gmail.com
- Update to 5.22.0 (boo#980066)
  * KNewPasswordWidget: Remove size hint on spacer, which was
    leading to some always empty space in the layout
  * KNewPasswordWidget: fix QPalette when widget is disabled
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.22.0.php
* Mon Apr  4 2016 hrvoje.senjan@gmail.com
- Update to 5.21.0 (boo#974793)
  * Take content margins into account when calculating size hints
  * Upgrade Qt version requirement to 5.4.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.21.0.php
* Sun Mar  6 2016 hrvoje.senjan@gmail.com
- Update to 5.20.0 (boo#970856)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.20.0.php
* Sat Feb  6 2016 hrvoje.senjan@gmail.com
- Update to 5.19.0 (boo#967668)
  * Fix buddy widgets working with KFontRequester
  * KNewPasswordDialog: use KMessageWidget
  * Prevent crash-on-exit in KSelectAction::~KSelectAction
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.19.0.php
* Sat Jan  2 2016 hrvoje.senjan@gmail.com
- Update to 5.18.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.18.0.php
* Thu Dec 10 2015 hrvoje.senjan@gmail.com
- Update to 5.17.0
  * Fix a small artifact of KRatingWidget on hi-dpi.
  * Refactor and fix the feature introduced in bug 171343
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.17.0.php
* Sun Nov  8 2015 hrvoje.senjan@gmail.com
- Update to 5.16.0 (boo#955067)
  * Add collapsible container widget, KCollapsibleGroupBox
  * KNewPasswordWidget: missing color initialization
  * Introduce KNewPasswordWidget
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.16.0.php
* Mon Oct  5 2015 hrvoje.senjan@gmail.com
- Update to 5.15.0
  * Fix warning C4138 (MSVC): '*/' found outside of comment
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.15.0.php
* Tue Sep  8 2015 hrvoje.senjan@gmail.com
- Update to 5.14.0
  * KPasswordDialog: let the user change the password visibility
    (kde#224686)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.14.0.php
* Tue Aug  4 2015 hrvoje.senjan@gmail.com
- Update to 5.13.0
  * The Qt version requirement has been bumped from 5.2 to 5.3
  * Debug output has been ported to categorized output, for less
    noise by default
  * Docbook documentation has been reviewed and updated
  * New API taking QIcon parameters to set the icons in
    the tab bar
  * KCharSelect: Fix unicode category and use boundingRect
    for width calculation
  * KCharSelect: fix cell width to fit contents
  * KMultiTabBar margins now are ok on HiDPI screens
  * KRuler: deprecate unimplemented KRuler::setFrameStyle(),
    clean up comments
  * KEditListWidget: remove margin, so it aligns better with
    other widgets
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.13.0.php
* Sun Jul  5 2015 hrvoje.senjan@gmail.com
- Update to 5.12.0
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.12.0.php
* Sun Jun  7 2015 hrvoje.senjan@gmail.com
- Update to 5.11.0
  * KAssistantDialog: Re-add the Help button that was present in
    KDELibs4 version
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.11.0.php
* Sun May  3 2015 hrvoje.senjan@gmail.com
- Update to 5.10.0
  * KDateTimeEdit: Fix so user input actually gets registered.
    Fix double margins.
  * KFontRequester: fix selecting monospaced fonts only
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.10.0.php
* Sat Apr  4 2015 hrvoje.senjan@gmail.com
- Update to 5.9.0
  * Make KMessageWidget animation smooth with high Device Pixel Ratio
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.9.0.php
* Sat Mar  7 2015 hrvoje.senjan@gmail.com
- Update to 5.8.0
  * Make KRatingWidget cope with devicePixelRatio
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.8.0.php
* Sun Feb  8 2015 hrvoje.senjan@gmail.com
- Update to 5.7.0
  * Use kstyleextensions to specify custom control element for
    rendering kcapacity bar when supported, this allow the widget
    to be styled properly
  * Provide an accessible name for KLed
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.7.0.php
* Sat Jan  3 2015 hrvoje.senjan@gmail.com
- Update to 5.6.0
  * Add runtime style element extension convenience functions
    for widgets: KStyleExtensions
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.6.0.php
* Sat Dec  6 2014 hrvoje.senjan@gmail.com
- Update to 5.5.0
  * Add class KSplitterCollapserButton, a button which appears
    on the side of a splitter handle and allows easy collapsing
    of the widget on the opposite side
  * Support monochrome icon themes (such as breeze)
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.5.0.php
* Sun Nov  2 2014 hrvoje.senjan@gmail.com
- Update to 5.4.0
  * New function KMimeTypeEditor::editMimeType(),
    to launch keditfiletype5
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.4.0.php
* Sat Oct  4 2014 hrvoje.senjan@gmail.com
- Update to 5.3.0
  * KPageListView: fixes for high-dpi mode
  * KPageWidget: margin fixes
  * For more details please see:
    https://www.kde.org/announcements/kde-frameworks-5.3.0.php
* Tue Sep  9 2014 hrvoje.senjan@gmail.com
- Update to 5.2.0
  * KWidgetsAddons: new class KColumnResizer (makes it easy to
    vertically align widgets across groups)
  * For more details please see:
    http://kde.org/announcements/kde-frameworks-5.2.php
- Added pkgconfig(Qt5UiTools) BuildRequires
* Sat Aug  2 2014 hrvoje.senjan@gmail.com
- Update to 5.1.0
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.1.php
- Harden required Qt5 libs versions
- Pass the location of lconvert executable
* Tue Jul  1 2014 hrvoje.senjan@gmail.com
- Update to 5.0.0
  * Final release of KDE Frameworks 5
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/kde-frameworks-5.0.php
* Sun Jun  1 2014 hrvoje.senjan@gmail.com
- Update to 4.100.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta3.php
- Added libqt5-linguist-devel BuildRequires
- Add baselibs.conf
* Sun May  4 2014 hrvoje.senjan@gmail.com
- Update to 4.99.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta2.php
* Sat Mar 29 2014 hrvoje.senjan@gmail.com
- Update to 4.98.0
  * API improvements and cleanups
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-beta1.php
* Tue Mar  4 2014 hrvoje.senjan@gmail.com
- Update to 4.97.0:
  * Buildsystem fixes
  * For more details please see:
    http://www.kde.org/announcements/announce-frameworks5-alpha2.php
* Sat Feb  8 2014 hrvoje.senjan@gmail.com
- Init kwidgetsaddons package
